![lilbulb](assets/lilbulb.png)

Dave's lil' bulb - small function lib for creating ilidata.xml files and other utilities...

```
pip install lilbulb
```

```
>>> import lilbulb
>>> lilbulb.make_ilidata('.','daves_kbs15', 'mailto:signedav@lilbulb.ws', '2022-05-11', '2022-05-31', ['KbS_V1_5'])

```